@@ -4,11 +4,11 @@ Exceptions
 ----------
 
 """
-__author__ = 'Richard Smith'
-__date__ = '02 Jun 2021'
-__copyright__ = 'Copyright 2018 United Kingdom Research and Innovation'
-__license__ = 'BSD - see LICENSE file in top-level package directory'
-__contact__ = 'richard.d.smith@stfc.ac.uk'
+__author__ = "Richard Smith"
+__date__ = "02 Jun 2021"
+__copyright__ = "Copyright 2018 United Kingdom Research and Innovation"
+__license__ = "BSD - see LICENSE file in top-level package directory"
+__contact__ = "richard.d.smith@stfc.ac.uk"
 
 
 class NoPluginsError(Exception):
@@ -17,4 +17,5 @@ class NoPluginsError(Exception):
     i.e. if no input plugins were successfully loaded, then this exception
     would be raised.
     """
-    pass
\ No newline at end of file
+
+    pass
