@@ -9,17 +9,19 @@ __copyright__ = "Copyright 2018 United Kingdom Research and Innovation"
 __license__ = "BSD - see LICENSE file in top-level package directory"
 __contact__ = "richard.d.smith@stfc.ac.uk"
 
-import logging
-from functools import lru_cache
 
-# Typing imports
-from typing import List, Optional
+import logging
 
 # Python imports
+from functools import lru_cache
+from pathlib import Path
+from typing import Dict, List, Optional
+
 import yaml
 
 # 3rd Party Imports
 from directory_tree import DatasetNode
+from pydantic import BaseModel
 
 # Package imports
 from asset_scanner.core.utils import dict_merge, load_description_files
@@ -27,82 +29,45 @@ from asset_scanner.core.utils import dict_merge, load_description_files
 LOGGER = logging.getLogger(__name__)
 
 
-class ItemDescription:
-    """
-    Container to provide convenient access points into parts of
-    the item description.
-    """
+class Processor(BaseModel):
+    """Common model for processor."""
 
-    def __init__(self, description):
-        self._description = description
+    defaults: Optional[Dict] = {}
+    mappings: Optional[Dict] = {}
+    overrides: Optional[Dict] = {}
+    extraction_methods: List[Dict] = []
+
+
+class Category(BaseModel):
+    """Category label model."""
+
+    label: str
+    regex: str
+
+
+class Collections(Processor):
+    """Collections processor description model."""
+
+    id: Optional[str]
+
+
+class Facets(Processor):
+    """Facets processor description model."""
+
+    aggregation_facets: Optional[List] = []
+    search_facets: Optional[List] = []
+
+
+class ItemDescription(BaseModel):
+    """Top level container for ItemDescriptions."""
+
+    paths: List
+    collections: Optional[Collections] = {}
+    facets: Optional[Facets] = {}
+    categories: Optional[List[Category]] = []
 
     def __repr__(self):
-        return yaml.dump(self._description)
-
-    @property
-    def defaults(self) -> dict:
-        """Returns defaults"""
-        return self._description.get("defaults", {})
-
-    @property
-    def overrides(self) -> Optional[dict]:
-        """Returns overrides"""
-        return self._description.get("overrides")
-
-    @property
-    def mappings(self) -> Optional[dict]:
-        """Returns mappings"""
-        return self._description.get("mappings")
-
-    @property
-    def allowed_facets(self) -> List:
-        """Returns allowed facets"""
-        return self.facet_extract_conf.get("allowed_facets", [])
-
-    @property
-    def extraction_methods(self) -> List[dict]:
-        """Returns extraction methods"""
-        return self.facet_extract_conf.get("extraction_methods", [])
-
-    @property
-    def aggregation_facets(self) -> List:
-        """Returns aggregation facets"""
-        return self.facet_extract_conf.get("aggregation_facets", [])
-
-    @property
-    def facet_extract_conf(self) -> dict:
-        """Returns facets key"""
-        return self._description.get("facets", {})
-
-    @property
-    def categories(self):
-        """Returns categories"""
-        return self._description.get("categories", [])
-
-    @property
-    def collection(self):
-        """Returns collection"""
-        return self._description.get("collection", {})
-
-    @property
-    def search_facets(self) -> List:
-        """Returns extra top level facets"""
-        return self.facet_extract_conf.get("search_facets", [])
-
-    @property
-    def templates(self):
-        """Return the templates section of the description"""
-        return self._description.get("templates", {})
-
-    @property
-    def title_template(self):
-        """Returns the template for the title"""
-        return self.templates.get("title_template")
-
-    @property
-    def description_template(self):
-        """Returns the template for the title"""
-        return self.templates.get("description_template")
+        return yaml.dump(self.dict())
 
 
 class ItemDescriptions:
@@ -111,25 +76,30 @@ class ItemDescriptions:
     and returning an :py:obj:`ItemDescription`
     """
 
-    def __init__(self, root_path: str):
+    def __init__(
+        self, root_path: Optional[str] = None, filelist: Optional[List] = None
+    ):
         """
 
         :param root_path: Path to the root of the yaml store
+        :param filelist: Can supply a set of yml files to load. If present, root_path is ignored.
         """
 
         self.tree = DatasetNode()
 
-        self._build_tree(root_path)
+        self._build_tree(root_path, filelist)
 
-    def _build_tree(self, root_path: str) -> None:
+    def _build_tree(self, root_path: str, files: List[Path]) -> None:
         """
         Loads the yaml files from the root path and builds the dataset tree
         with references to the yaml files.
 
         :param root_path: Path at the top of the yaml file tree
+        :param files: List of files to open.
         """
 
-        files = load_description_files(root_path)
+        if not files:
+            files = load_description_files(root_path)
 
         if not files:
             LOGGER.error(
@@ -142,9 +112,8 @@ class ItemDescriptions:
             with open(file) as reader:
                 data = yaml.safe_load(reader)
 
-                for dataset in data.get("datasets", []):
-                    # Strip trailing slash.
-                    # Needed to make sure tree search works
+                for dataset in data.get("paths", []):
+                    # Strip trailing slash. Needed to make sure tree search works
                     dataset = dataset.rstrip("/")
 
                     self.tree.add_child(dataset, description_file=file.as_posix())
@@ -179,7 +148,7 @@ class ItemDescriptions:
 
         config_description = self.load_config(*description_files)
 
-        return ItemDescription(config_description)
+        return ItemDescription(**config_description)
 
     @lru_cache(100)
     def load_config(self, *args: str) -> dict:
@@ -200,13 +169,15 @@ if __name__ == "__main__":
     import argparse
 
     parser = argparse.ArgumentParser()
-    parser.add_argument("root")
+    parser.add_argument(
+        "root", help="root from which to load all the yaml description files"
+    )
+    parser.add_argument("path", help="path to retrieve description for")
+
     args = parser.parse_args()
 
     descriptions = ItemDescriptions(args.root)
 
-    description = descriptions.get_description(
-        "/badc/faam/data/2005/b069-jan-05/core_processed/core_faam_20050105_r0_b069.nc"
-    )
+    description = descriptions.get_description(args.path)
 
     print(description)
