@@ -2,11 +2,11 @@
 """
 
 """
-__author__ = 'Richard Smith'
-__date__ = '07 Jun 2021'
-__copyright__ = 'Copyright 2018 United Kingdom Research and Innovation'
-__license__ = 'BSD - see LICENSE file in top-level package directory'
-__contact__ = 'richard.d.smith@stfc.ac.uk'
+__author__ = "Richard Smith"
+__date__ = "07 Jun 2021"
+__copyright__ = "Copyright 2018 United Kingdom Research and Innovation"
+__license__ = "BSD - see LICENSE file in top-level package directory"
+__contact__ = "richard.d.smith@stfc.ac.uk"
 
 from abc import ABC, abstractmethod
 
@@ -27,7 +27,7 @@ class BaseProcessor(ABC):
             setattr(self, k, v)
 
     @abstractmethod
-    def run(self, filepath: str, media_source: str = 'POSIX', **kwargs) -> dict:
+    def run(self, filepath: str, media_source: str = "POSIX", **kwargs) -> dict:
         """
         The action of running the processor and returning an output
         :param filepath: Path to object
