@@ -11,12 +11,12 @@ Input plugins are loaded as named entry points with the namespace:
 
 .. warning::
     Blocking input plugins will prevent others from being run. They are run
-    sequentially. For example, with the `file system input`_ plugin, you could configure
-    several to scan multiple directories but the rabbit plugin creates a listening connection
-    which would block any other inputs.
+    sequentially. For example, with the `file system input`_ plugin, you
+    could configure several to scan multiple directories but the rabbit plugin
+    creates a listening connection which would block any other inputs.
 """
-__author__ = 'Richard Smith'
-__date__ = '08 Jun 2021'
-__copyright__ = 'Copyright 2018 United Kingdom Research and Innovation'
-__license__ = 'BSD - see LICENSE file in top-level package directory'
-__contact__ = 'richard.d.smith@stfc.ac.uk'
\ No newline at end of file
+__author__ = "Richard Smith"
+__date__ = "08 Jun 2021"
+__copyright__ = "Copyright 2018 United Kingdom Research and Innovation"
+__license__ = "BSD - see LICENSE file in top-level package directory"
+__contact__ = "richard.d.smith@stfc.ac.uk"
