@@ -2,24 +2,26 @@
 """
 
 """
-__author__ = 'Richard Smith'
-__date__ = '02 Jun 2021'
-__copyright__ = 'Copyright 2018 United Kingdom Research and Innovation'
-__license__ = 'BSD - see LICENSE file in top-level package directory'
-__contact__ = 'richard.d.smith@stfc.ac.uk'
+__author__ = "Richard Smith"
+__date__ = "02 Jun 2021"
+__copyright__ = "Copyright 2018 United Kingdom Research and Innovation"
+__license__ = "BSD - see LICENSE file in top-level package directory"
+__contact__ = "richard.d.smith@stfc.ac.uk"
 
 from abc import ABC, abstractmethod
+
 from asset_scanner.core import BaseExtractor
 from asset_scanner.core.utils import load_plugins
 from asset_scanner.types.source_media import StorageType
 
 
 class BaseInputPlugin(ABC):
-
     def __init__(self, **kwargs):
         self.filters = None
-        if kwargs.get('filters'):
-            self.filters = load_plugins(kwargs, 'asset_scanner.plugin_filters', 'filters')
+        if kwargs.get("filters"):
+            self.filters = load_plugins(
+                kwargs, "asset_scanner.plugin_filters", "filters"
+            )
 
     def should_process(self, filepath, source_media: StorageType) -> bool:
         """
